#! /usr/bin/env python
"""
    Usage: cat min_below_minus_40.txt | ./process_consecutive.py

    Reads temperature data in this format:

    1946-12-06	-42.5	-36.5	-31.5
    1946-12-07	-45.6	-42.4	-38.6
    1946-12-08	-49.5	-47.1	-39.6

    (date, min, avg, max)

    Identifies the blocks of consecutive dates, and prints summary 
    information about each block.
    
    Copyright (C) Christopher Swingley <cswingle@gmail.com> and
    licensed under the terms of the GNU General Public License
    version 2.
"""

import sys
import datetime

previous_date = None
count = 0
min_sum = 0.0
avg_sum = 0.0
max_sum = 0.0
start_date = None
for line in sys.stdin.readlines():
    line = line.strip()
    (date, min, avg, max) = line.split()
    if max == r'\N':
        max = (float(avg) - float(min)) + float(avg)
    (year, month, day) = date.split('-')
    (year, month, day) = map(int, (year, month, day))
    (min, avg, max) = map(float, (min, avg, max))
    current_date = datetime.date(year, month, day)
    if not previous_date:
        previous_date = current_date - datetime.timedelta(1)
    if not start_date:
        start_date = current_date
    if previous_date != current_date - datetime.timedelta(1):
        if count > 5:
            print "For period between %s and %s" % (start_date, previous_date)
            print " Days = %d" % count
            print " Average temp = %5.1f" % (avg_sum / count)
            print " Average minimum = %5.1f" % (min_sum / count)
            print " Cumulative degrees below freezing = %6.1f" % ((32.0 - (avg_sum / count)) * count)
        start_date = current_date
        count = 0
        avg_sum = 0.0
        min_sum = 0.0
    count += 1
    avg_sum += avg
    min_sum += min
    previous_date = current_date
if count > 5:
    print "For period between %s and %s" % (start_date, previous_date)
    print " Days = %d" % count
    print " Average temp = %5.1f" % (avg_sum / count)
    print " Average minimum = %5.1f" % (min_sum / count)
    print " Cumulative degrees below freezing = %6.1f" % ((32.0 - (avg_sum / count)) * count)
